package com.zehong.framework.web.service;

import com.zehong.system.domain.TPractitionerInfo;
import com.zehong.system.service.ITPractitionerInfoService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;
import com.zehong.common.core.domain.entity.SysUser;
import com.zehong.common.core.domain.model.LoginUser;
import com.zehong.common.enums.UserStatus;
import com.zehong.common.exception.BaseException;
import com.zehong.common.utils.StringUtils;
import com.zehong.system.service.ISysUserService;

import java.util.List;

/**
 * 用户验证处理
 *
 * @author zehong
 */
@Service
public class UserDetailsServiceImpl implements UserDetailsService
{
    private static final Logger log = LoggerFactory.getLogger(UserDetailsServiceImpl.class);

    @Autowired
    private ISysUserService userService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private ITPractitionerInfoService tPractitionerInfoService;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException
    {
        String lastChar = String.valueOf(username.charAt(username.length() - 1));
        if (lastChar.equals("Y")){
            String usernames = StringUtils.substringBefore(username, "Y");
            TPractitionerInfo tPractitionerInfo=new TPractitionerInfo();
            tPractitionerInfo.setTelNum(usernames);
            /**
             * 查询登录信息
             */
            List<TPractitionerInfo> tPractitionerInfos = tPractitionerInfoService.loginTPractitioner(tPractitionerInfo);
            if (tPractitionerInfos.size()<=0){
                log.info("登录用户：{} 不存在.", usernames);
                throw new UsernameNotFoundException("登录用户：" + usernames + " 不存在");
            }else {
                SysUser user=new SysUser();
                user.setUserName(tPractitionerInfos.get(0).getTelNum());
                user.setPassword(tPractitionerInfos.get(0).getPassword());
                user.setNickName(tPractitionerInfos.get(0).getName());
                user.setAvatar(tPractitionerInfos.get(0).getPersonPhoto());
                user.setStationName(tPractitionerInfos.get(0).getStationName());
                user.setUserId(tPractitionerInfos.get(0).getPractitionerId());
                user.setDeptId(Long.valueOf(-2));
                return createLoginUser(user);
            }
        }else {
            System.out.println(username);
            SysUser user = userService.selectUserByUserName(username);

            if (StringUtils.isNull(user))
            {
                log.info("登录用户：{} 不存在.", username);
                throw new UsernameNotFoundException("登录用户：" + username + " 不存在");
            }
            else if (UserStatus.DELETED.getCode().equals(user.getDelFlag()))
            {
                log.info("登录用户：{} 已被删除.", username);
                throw new BaseException("对不起，您的账号：" + username + " 已被删除");
            }
            else if (UserStatus.DISABLE.getCode().equals(user.getStatus()))
            {
                log.info("登录用户：{} 已被停用.", username);
                throw new BaseException("对不起，您的账号：" + username + " 已停用");
            }
            System.out.println(user);
            return createLoginUser(user);
        }

    }

    public UserDetails createLoginUser(SysUser user)
    {
        return new LoginUser(user, permissionService.getMenuPermission(user));
    }
}
